# Security policy

## Reporting a vulnerability

If you have found a possible vulnerability, please open an Issue and label it with the tag `security`.

## Bug bounties

We do not currently run any bug bounty programs.

## Vulnerability disclosures

Critical vulnerabilities will be disclosed via GitHub's
[security advisory](https://github.com/promptromp/pdfalive/security) system.
